(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     90859,       2813]
NotebookOptionsPosition[     83562,       2573]
NotebookOutlinePosition[     84017,       2591]
CellTagsIndexPosition[     83974,       2588]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Code from \"Glimpses of Soliton Theory\""
}], "Title",
 CellChangeTimes->{{3.443283669134124*^9, 3.443283678035811*^9}}],

Cell["\<\
Alex Kasman
September 2010\
\>", "Subtitle",
 CellChangeTimes->{{3.494775152264514*^9, 3.494775158405052*^9}}],

Cell[CellGroupData[{

Cell["Chapter 1 MyAnimate  and SimpleEvolver", "Section",
 CellChangeTimes->{{3.44328212785538*^9, 3.443282148452435*^9}, {
  3.471796682652899*^9, 3.4717966850387173`*^9}, {3.471796962999517*^9, 
  3.471796979124291*^9}}],

Cell["\<\
The cell below actually defines TWO commands: one for animating the graph of \
a function of x and t as a curve that evolves and one for animating a \
function of x, y and t as a surface that evolves:\
\>", "Text",
 CellChangeTimes->{{3.44328215745478*^9, 3.4432821876675653`*^9}, {
  3.494775178324778*^9, 3.494775180652692*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MyAnimate", "[", 
    RowBox[{"f_", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "x0_", ",", "x1_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "y0_", ",", "y1_"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "t0_", ",", "t1_"}], "}"}], ",", "n_"}], "]"}], ":=", 
   
   RowBox[{"ListAnimate", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{"f", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "x0", ",", "x1"}], "}"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"y0", ",", "y1"}], "}"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "t0", ",", "t1", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"t1", "-", "t0"}], ")"}], "/", "n"}]}], "}"}]}], "]"}], 
    "]"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MyAnimate", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "x0_", ",", "x1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "y0_", ",", "y1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "z0_", ",", "z1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0_", ",", "t1_"}], "}"}], ",", "n_"}], "]"}], ":=", 
  RowBox[{"ListAnimate", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Plot3D", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "x0", ",", "x1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "y0", ",", "y1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"z0", ",", "z1"}], "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "t0", ",", "t1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t1", "-", "t0"}], ")"}], "/", "n"}]}], "}"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{3.494775173986506*^9}],

Cell["\<\


This code animates the APPROXIMATE dynamics of a solution to the equation u_t \
= u*(u - u_x) with a given initial profile by showing what it would look like \
tsize units of time later.  (It is more accurate for smaller values of tsize, \
and you can alter this in the definition.)    Moreover, changing the line \
that starts RHS =. .. will allow you to change it to do the same thing to any \
other equation of the form u_t = (stuff not involving t derivatives).\
\>", "Text",
 CellChangeTimes->{{3.443282229757188*^9, 3.443282345104162*^9}, {
  3.473161396806233*^9, 3.473161397236434*^9}, {3.494775187417588*^9, 
  3.494775192733077*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SimpleEvolver", "[", 
    RowBox[{"profile_", ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "x0_", ",", " ", "x1_"}], "}"}]}], "]"}], " ", ":=",
    " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"RHS", " ", "=", " ", 
      RowBox[{"profile", " ", 
       RowBox[{"(", 
        RowBox[{"profile", " ", "-", " ", 
         RowBox[{"D", "[", 
          RowBox[{"profile", ",", " ", "x"}], "]"}]}], ")"}]}]}], ";", "\n", 
     "    ", 
     RowBox[{"numpts", " ", "=", " ", "1000"}], ";", "\n", "    ", 
     RowBox[{"tsize", " ", "=", " ", ".1"}], ";", "\n", "    ", 
     RowBox[{"profiletable", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", 
          RowBox[{"(", 
           RowBox[{"profile", " ", "/.", " ", 
            RowBox[{"x", " ", "->", " ", "xi"}]}], ")"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", "x0", ",", " ", "x1", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", " ", "-", " ", "x0"}], ")"}], "/", "numpts"}]}], 
         "}"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"evolvedtable", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"profile", " ", "+", " ", 
             RowBox[{"tsize", " ", "RHS"}]}], " ", "/.", " ", 
            RowBox[{"x", " ", "->", " ", "xi"}]}], ")"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"xi", ",", " ", "x0", ",", " ", "x1", ",", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"x1", " ", "-", " ", "x0"}], ")"}], "/", "numpts"}]}], 
         "}"}]}], "]"}]}], ";", "\n", "    ", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", "profiletable", "]"}], ",", " ", 
          RowBox[{"Dashing", "[", ".01", "]"}], ",", " ", 
          RowBox[{"Line", "[", "evolvedtable", "]"}]}], "}"}], "]"}], ",", 
       " ", 
       RowBox[{"Axes", " ", "->", " ", "True"}]}], "]"}]}], ")"}]}], 
  "\n"}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.483258785530251*^9, 3.483258796991585*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 2 AnimBurgers (Burgers Equation)", "Section",
 CellChangeTimes->{{3.443282432656147*^9, 3.443282438629882*^9}, {
  3.471796782212636*^9, 3.471796782992079*^9}, {3.4717970453659563`*^9, 
  3.471797060533765*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnimBurgers", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "a_", ",", "b_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"liszt", ",", "i", ",", "j", ",", "n", ",", "min", ",", "max"}], 
     "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"liszt", "[", "0", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"N", "[", 
           RowBox[{"f", "/.", 
            RowBox[{"x", "\[Rule]", "i"}]}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", 
          RowBox[{"a", "-", 
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}]}], ",", 
          RowBox[{"b", "+", 
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"min", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"f", "/.", 
           RowBox[{"x", "\[Rule]", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a", ",", "b", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"max", "=", 
      RowBox[{"Max", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"f", "/.", 
           RowBox[{"x", "\[Rule]", "i"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "a", ",", "b", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"b", "-", "a"}], ")"}], "/", "100"}]}], "}"}]}], "]"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "\[LessEqual]", "100"}], ",", 
       RowBox[{"i", "=", 
        RowBox[{"i", "+", "1"}]}], ",", 
       RowBox[{
        RowBox[{"liszt", "[", "i", "]"}], "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"liszt", "[", 
               RowBox[{"i", "-", "1"}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"j", ",", "1"}], "]"}], "]"}], "+", 
             RowBox[{".1", " ", 
              RowBox[{
               RowBox[{"liszt", "[", 
                RowBox[{"i", "-", "1"}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"j", ",", "2"}], "]"}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"liszt", "[", 
              RowBox[{"i", "-", "1"}], "]"}], "[", 
             RowBox[{"[", 
              RowBox[{"j", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "1", ",", 
            RowBox[{"Length", "[", 
             RowBox[{"liszt", "[", "0", "]"}], "]"}]}], "}"}]}], "]"}]}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"ListAnimate", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"AbsoluteThickness", "[", "2", "]"}], ",", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{"Line", "[", 
              RowBox[{"liszt", "[", "i", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"Axes", "\[Rule]", "True"}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", ".5"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"a", ",", "b"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"min", "-", 
                RowBox[{".2", " ", 
                 RowBox[{"(", 
                  RowBox[{"max", "-", "min"}], ")"}]}]}], ",", 
               RowBox[{"max", "+", 
                RowBox[{".2", " ", 
                 RowBox[{"(", 
                  RowBox[{"max", "-", "min"}], ")"}]}]}]}], "}"}]}], 
            "}"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "99", ",", "1"}], "}"}]}], "]"}], 
      "]"}]}]}], "]"}]}]], "Input"],

Cell["\<\
The code above defines a command takes a function of x (and only x) and a \
range of x values as its argument.  It then illustrates the dynamics of a \
solution with that initial profile under the evolution induced by the IVB \
equation by moving each point to the right at a speed proportional to its \
height.  (Unfortunately, we cannot write a closed formula for this in most \
situaions, and it often stops being the graph of a function after a short \
amount of time.)\
\>", "Text",
 CellChangeTimes->{{3.44328249827944*^9, 3.443282577347246*^9}, {
  3.494775252760529*^9, 3.494775264886672*^9}}],

Cell["\<\
For example, the cell below will animate the dynamics flowing from an initial \
condition shaped like a \"bell curve\" with a single hump.\
\>", "Text",
 CellChangeTimes->{{3.494775231504669*^9, 3.494775242213584*^9}, {
  3.494775272982346*^9, 3.494775313119676*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"AnimBurgers", "[", 
   RowBox[{
    RowBox[{"1", "+", 
     RowBox[{".5", " ", 
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"-", 
         RowBox[{"x", "^", "2"}]}], ")"}]}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "2"}], ",", "8"}], "}"}]}], "]"}], "\n"}]], "Input",
 CellChangeTimes->{{3.443282486107095*^9, 3.4432824891439238`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Chapter 3 usol and u2sol (the general 1-solution solution and a particular \
2-soliton solution to the KdV equation)\
\>", "Section",
 CellChangeTimes->{{3.443282821419016*^9, 3.443282827597438*^9}, {
  3.443283033979579*^9, 3.443283034875185*^9}, {3.4432835333432293`*^9, 
  3.443283543286147*^9}, {3.443283643996009*^9, 3.443283648971768*^9}, {
  3.4717970664869213`*^9, 3.47179707887897*^9}, {3.473161387958055*^9, 
  3.473161389579623*^9}}],

Cell["\<\
As part of a homework problem, you are supposed to write a command which \
takes in a function of x and t and outputs the number zero if it is a \
solution.  I am putting a definition here just as a placeholder for this \
command:\
\>", "Text",
 CellChangeTimes->{{3.4741903112138653`*^9, 3.4741903493805933`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KdV", "[", "v_", "]"}], ":=", 
   RowBox[{
   "Print", "[", 
    "\"\<You are supposed to create your own KdV[] command.  Please write \
one. -Alex\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.474190350998053*^9, 3.474190403385339*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"usol", "[", 
   RowBox[{"x_", ",", "t_", ",", "k_"}], "]"}], ":=", 
  RowBox[{"8", 
   RowBox[{
    RowBox[{"k", "^", "2"}], "/", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"k", " ", "x"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}], "+", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "k"}], " ", "x"}], " ", "-", " ", 
         RowBox[{
          RowBox[{"k", "^", "3"}], " ", "t"}]}], "]"}]}], ")"}], "^", 
     "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.408982782904517*^9, 3.408982800142632*^9}, {
  3.443282835828529*^9, 3.4432828367058268`*^9}}],

Cell["\<\
The formula above solves the KdV equation for every value of k.  It is a \
solitary wave of height 2k^2 travelling to the left with speed k^2, as these \
two examples illustrate:\
\>", "Text",
 CellChangeTimes->{{3.44328288654286*^9, 3.4432829292675447`*^9}, {
  3.494775342773389*^9, 3.4947753463527412`*^9}}],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"usol", "[", 
    RowBox[{"x", ",", "t", ",", "1"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.443282841390106*^9, 3.443282862328362*^9}}],

Cell[BoxData[
 RowBox[{"MyAnimate", "[", 
  RowBox[{
   RowBox[{"usol", "[", 
    RowBox[{"x", ",", "t", ",", "2"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "1"}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.443282841390106*^9, 3.443282875632957*^9}}],

Cell["\<\
Here is a formula for a 2-soliton solution in which we see peaks that look \
very much like the two illustrated above, but now they appear TOGETHER in a \
solution...and it is NOT just a sum of the previous two solutions!\
\>", "Text",
 CellChangeTimes->{{3.443282962853112*^9, 3.4432829983863277`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"u2sol", "[", 
   RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"24", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"t", "+", "x"}], ")"}]}]], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}]]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"20", " ", "t"}], "+", 
         RowBox[{"8", " ", "x"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"34", " ", "t"}], "+", 
        RowBox[{"10", " ", "x"}]}]]}], ")"}]}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"t", "+", "x"}], ")"}]}]]}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}]], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}]]}]}], ")"}], 
    "2"]]}]], "Input",
 CellChangeTimes->{{3.443283003726342*^9, 3.443283016366675*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 4 Elliptic Solutions to KdV: uell", "Section",
 CellChangeTimes->{{3.443282704382225*^9, 3.4432827092329597`*^9}, {
  3.443283638280884*^9, 3.443283639627708*^9}, {3.4717970839188013`*^9, 
  3.4717970963585176`*^9}}],

Cell["\<\
For any values of the constant parameters c, omega, k1 and k2 this is a \
solution to the KdV equation made out of the Weirstrass p-function for the \
curve with parameters k1 and k2.\
\>", "Text",
 CellChangeTimes->{{3.443282716776655*^9, 3.4432827484633017`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"uell", "[", 
   RowBox[{
   "x_", ",", "t_", ",", "c_", ",", "omega_", ",", "k1_", ",", "k2_"}], "]"}],
   ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"WeierstrassP", "[", 
     RowBox[{
      RowBox[{"x", "+", 
       RowBox[{"c", " ", "t"}], "+", "omega"}], ",", 
      RowBox[{"{", 
       RowBox[{"k1", ",", "k2"}], "}"}]}], "]"}]}], "+", 
   RowBox[{"2", 
    RowBox[{"c", "/", "3"}]}]}]}]], "Input",
 CellChangeTimes->{3.443549062363452*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 5 maketau and makeu", "Section",
 CellChangeTimes->{{3.4432830873957872`*^9, 3.443283091831626*^9}, {
  3.4717970906461487`*^9, 3.471797093766285*^9}}],

Cell["\<\
This command just turns a function into 2 times its second logarithmic \
derivative:\
\>", "Text",
 CellChangeTimes->{{3.443283331946959*^9, 3.443283344354203*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeu", "[", "tau_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"2", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Log", "[", "tau", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "2"}], "}"}]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.4432833269944077`*^9}],

Cell["\<\
If tau[x,t] is a function which turns into a solution of KdV when you apply \
makeu, then we call it \"a tau-function of the KdV equation\".  As it turns \
out, it is often easier to write the tau-function than the solution.  For \
example, the solution -2/x^2 that we have encountered before comes from tau=x:\
\>", "Text",
 CellChangeTimes->{{3.443283348834179*^9, 3.443283427152458*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeu", "[", "x", "]"}]], "Input",
 CellChangeTimes->{{3.443283428451769*^9, 3.443283430370734*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["2", 
   SuperscriptBox["x", "2"]]}]], "Output",
 CellChangeTimes->{3.4432834312681217`*^9, 3.445679566372615*^9, 
  3.475858878370949*^9, 3.478614052826974*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"maketau", "[", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"a_", ",", "b_"}], "}"}], "}"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"b", " ", "x"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"b", "^", "3"}], " ", "t"}]}], "]"}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "b"}], " ", "x"}], " ", "-", " ", 
        RowBox[{
         RowBox[{"b", "^", "3"}], " ", "t"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"maketau", "[", "vec_", "]"}], ":=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Wronskian", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"maketau", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"vec", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"vec", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "}"}], "}"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "1", ",", 
           RowBox[{"Length", "[", "vec", "]"}]}], "}"}]}], "]"}], ",", "x"}], 
      "]"}], "]"}]}], "\n", "\n"}]}]], "Input",
 CellChangeTimes->{{3.443283100058921*^9, 3.4432831150569897`*^9}, {
  3.47591688717039*^9, 3.475916903881818*^9}, {3.477759775132249*^9, 
  3.4777597903576*^9}, {3.482619190237958*^9, 3.482619212698303*^9}, {
  3.494775478247892*^9, 3.494775497671198*^9}, {3.494775551483328*^9, 
  3.494775593284436*^9}, {3.4947756673637342`*^9, 3.494775682551764*^9}, {
  3.494775807254825*^9, 3.494775836648081*^9}, {3.494775879267108*^9, 
  3.494775907407084*^9}, {3.494775950243671*^9, 3.4947759636029377`*^9}}],

Cell["\<\
The command above takes a list of the form { {c1,k1}, {c2,k2}, \
{c3,k3},....,{cn,kn} } and turns it into a tau-function for a KdV solution \
(or, if you do not choose wisely, into the number zero).  The resulting \
solution will have n different things moving to the left (either soliton-like \
peaks or vertical asymptotes that go to negative infinity).  The parameters \
k1,..,kn determine the SPEEDS of those objects (they will have speeds k1^2, \
k2^2, ..., kn^2) and the c1,...,cn parameters will control both the positions \
and whether they are smooth soliton peaks or \"singularities' with vertical \
asymptotes.

For example:\
\>", "Text",
 CellChangeTimes->{{3.443283119545885*^9, 3.443283290979474*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makeu", "[", 
  RowBox[{"maketau", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.443283293369103*^9, 3.44328329606015*^9}, 
   3.443283467330964*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"12", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"4", " ", 
      RowBox[{"Cosh", "[", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"t", "+", "x"}], ")"}]}], "]"}]}], "+", 
     RowBox[{"Cosh", "[", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "t"}], "+", "x"}], ")"}]}], "]"}]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Sinh", "[", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "t"}], "+", "x"}], ")"}]}], "]"}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{
        RowBox[{"7", " ", "t"}], "+", "x"}], "]"}]}]}], ")"}], 
   "2"]]], "Output",
 CellChangeTimes->{
  3.443283468815792*^9, 3.445679566562972*^9, 3.475858878573163*^9, 
   3.4759169111026917`*^9, 3.478614053742278*^9, 3.494775699196294*^9, 
   3.494775788166441*^9, {3.494775980865728*^9, 3.494775988655737*^9}}]
}, Open  ]],

Cell["\<\
is the solution shown in the book as part of example 6.1.  It has one smooth \
peak and one vertical asymptote.  However, changing c2 from 1 to -1 makes it \
into the pure 2-soliton solution that we saw back in 4.5.\
\>", "Text",
 CellChangeTimes->{{3.443283471666088*^9, 3.44328355422202*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 6 Differential Operators", "Section",
 CellChangeTimes->{{3.443281885096765*^9, 3.443281895217861*^9}, {
  3.4432835967278423`*^9, 3.443283597580654*^9}, {3.443283653235672*^9, 
  3.443283654843585*^9}, {3.47179709971105*^9, 3.471797100774846*^9}, {
  3.4758578719964943`*^9, 3.475857874995687*^9}}],

Cell[CellGroupData[{

Cell["applying differential operators", "Subsection",
 CellChangeTimes->{{3.477924616401555*^9, 3.4779246267770967`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"odoapply", "[", 
    RowBox[{"ll_", ",", "f_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Sum", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"Coefficient", "[", 
          RowBox[{"ll", ",", "Dd", ",", "i"}], "]"}], " ", 
         RowBox[{"D", "[", 
          RowBox[{"f", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "i"}], "}"}]}], "]"}]}], " ", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Exponent", "[", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{"ll", ",", "Dd"}], "]"}], ",", "Dd"}], "]"}]}], "}"}]}], 
       "]"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.477924730993371*^9, 3.4779247316329317`*^9}, {
  3.477924819710334*^9, 3.477924839315772*^9}, {3.477925829038826*^9, 
  3.477925835507414*^9}, {3.477926066255986*^9, 3.477926153343961*^9}}],

Cell["\<\
Type the differential operator L as a polynomial in Dd with coefficients that \
are functions of x.  Then it can be applied to the function f using \
odoapply[L,f]\
\>", "Text",
 CellChangeTimes->{{3.477924644185833*^9, 3.477924684530148*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LL", "=", 
  RowBox[{
   RowBox[{"Dd", "^", "2"}], "-", 
   RowBox[{"2", "/", 
    RowBox[{"x", "^", "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.477924686045735*^9, 3.47792469470188*^9}, 
   3.48224520224751*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "2"], "-", 
  FractionBox["2", 
   SuperscriptBox["x", "2"]]}]], "Output",
 CellChangeTimes->{
  3.47792469524708*^9, 3.477924736022382*^9, 3.4779248431129103`*^9, 
   3.477925852811648*^9, {3.477926145137363*^9, 3.4779261555693502`*^9}, 
   3.478614049863529*^9, 3.480936612827733*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odoapply", "[", 
  RowBox[{"LL", ",", 
   RowBox[{"x", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"2", "x"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.477924695879726*^9, 3.4779247007572308`*^9}, {
   3.477924754498118*^9, 3.4779247618881073`*^9}, 3.482245206334032*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2", " ", "x"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", "x"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "2"]}]}], ")"}]}], "x"]], "Output",
 CellChangeTimes->{
  3.477924701849172*^9, {3.477924737741125*^9, 3.477924762407648*^9}, 
   3.477924844748481*^9, 3.477925853993876*^9, {3.4779261476378937`*^9, 
   3.477926156550865*^9}, 3.478614049912702*^9, 3.480936613166065*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multiplying Differential Operators", "Subsection",
 CellChangeTimes->{{3.444474784148168*^9, 3.444474788592413*^9}, {
  3.471797120425852*^9, 3.471797122342896*^9}, {3.47585786358983*^9, 
  3.4758578777270203`*^9}}],

Cell["Execute these definitions:", "Text",
 CellChangeTimes->{{3.444474835379912*^9, 3.444474842924233*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"odomult", "[", 
    RowBox[{"L_", ",", "M_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "f", ",", "rem"}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{
      RowBox[{"rem", "=", 
       RowBox[{"odoapply", "[", 
        RowBox[{"L", ",", 
         RowBox[{"odoapply", "[", 
          RowBox[{"M", ",", 
           RowBox[{
            RowBox[{"f", "'"}], "[", "x", "]"}]}], "]"}]}], "]"}]}], ";", 
      "\n", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{"Coefficient", "[", 
           RowBox[{"rem", ",", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"f", "'"}], "[", "x", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "i"}], "}"}]}], "]"}]}], "]"}], "]"}], " ", 
         RowBox[{"Dd", "^", "i"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", 
          RowBox[{"Exponent", "[", 
           RowBox[{
            RowBox[{"Collect", "[", 
             RowBox[{
              RowBox[{"L", "*", "M"}], ",", "Dd"}], "]"}], ",", "Dd"}], 
           "]"}]}], "}"}]}], "]"}]}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"odosimp", "[", "LL_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", ",", "i", ",", "L", ",", "outL"}], "}"}], ",", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"L", "=", 
       RowBox[{"Collect", "[", 
        RowBox[{"LL", ",", "Dd"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"Exponent", "[", 
        RowBox[{"L", ",", "Dd"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i", "=", "0"}], ";", 
         RowBox[{"outL", "=", "0"}]}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"n", "+", "1"}]}], ",", 
        RowBox[{"i", "=", 
         RowBox[{"i", "+", "1"}]}], ",", 
        RowBox[{"outL", "=", 
         RowBox[{"outL", "+", 
          RowBox[{
           RowBox[{"Simplify", "[", 
            RowBox[{"Coefficient", "[", 
             RowBox[{"L", ",", "Dd", ",", "i"}], "]"}], "]"}], " ", 
           RowBox[{"Dd", "^", "i"}]}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "outL"}], ")"}]}], "]"}]}], "\n"}], "Input",
 CellChangeTimes->{{3.444474776512616*^9, 3.444474826593281*^9}, 
   3.4446623347155333`*^9, 3.477924607749216*^9, {3.477925385047029*^9, 
   3.4779254783230953`*^9}, {3.477925515868528*^9, 3.477925574328168*^9}, {
   3.47792560457395*^9, 3.477925618186117*^9}, {3.477925708753602*^9, 
   3.477925711264248*^9}, {3.477925744995491*^9, 3.477925800167532*^9}}],

Cell["\<\
Now you can define differential operators using \"Dd\" for \"partial\":\
\>", "Text",
 CellChangeTimes->{{3.4444748535662193`*^9, 3.4444748747824306`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"LL", "=", 
  RowBox[{
   RowBox[{"Dd", "^", "2"}], "+", 
   RowBox[{"Sin", "[", "x", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"MM", "=", 
  RowBox[{
   RowBox[{"Dd", "^", "3"}], "-", 
   RowBox[{"x", " ", "Dd"}], " ", "+", " ", 
   RowBox[{"Exp", "[", "x", "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.4444748761534*^9, 3.444474891373898*^9}, {
  3.482245213214335*^9, 3.482245215942458*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "2"], "+", 
  RowBox[{"Sin", "[", "x", "]"}]}]], "Output",
 CellChangeTimes->{3.4444748926387053`*^9, 3.444643720361161*^9, 
  3.445679566844252*^9, 3.477817602166058*^9, 3.4779256228132057`*^9, 
  3.4779258706417313`*^9, 3.477926188264448*^9, 3.4786140499952602`*^9, 
  3.4809366141913767`*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "3"], "+", 
  SuperscriptBox["\[ExponentialE]", "x"], "-", 
  RowBox[{"Dd", " ", "x"}]}]], "Output",
 CellChangeTimes->{3.4444748926387053`*^9, 3.444643720361161*^9, 
  3.445679566844252*^9, 3.477817602166058*^9, 3.4779256228132057`*^9, 
  3.4779258706417313`*^9, 3.477926188264448*^9, 3.4786140499952602`*^9, 
  3.480936614195553*^9}]
}, Open  ]],

Cell["and you can compute their products with \"odomult[ , ]\":", "Text",
 CellChangeTimes->{{3.444474897386294*^9, 3.44447491202551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odomult", "[", 
  RowBox[{"LL", ",", "MM"}], "]"}]], "Input",
 CellChangeTimes->{{3.482245220205862*^9, 3.482245221357339*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "5"], "+", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["Dd", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "x"}], "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", "x"]}], "-", 
     RowBox[{"x", " ", 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.477925637983947*^9, 3.477925717409028*^9, 
  3.4779258078349667`*^9, 3.4779258731116877`*^9, 3.4779261923620777`*^9, 
  3.4786140501499434`*^9, 3.480936615221259*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odomult", "[", 
  RowBox[{"MM", ",", "LL"}], "]"}]], "Input",
 CellChangeTimes->{{3.444474917656485*^9, 3.444474920723687*^9}, {
  3.482245224445612*^9, 3.4822452259894857`*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "5"], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "x"], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "-", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", "x"}], ")"}], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["Dd", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "x"}], "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.444474921803941*^9, 3.4446437299238997`*^9, 
  3.4456795672022467`*^9, 3.477817602659267*^9, 3.47792588722046*^9, 
  3.4779261952769957`*^9, 3.478614050387436*^9, 3.4809366161711597`*^9}]
}, Open  ]],

Cell["Then, of course, their commutator is ", "Text",
 CellChangeTimes->{{3.444474923581192*^9, 3.444474927385318*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"comm", "=", 
  RowBox[{
   RowBox[{"odomult", "[", 
    RowBox[{"LL", ",", "MM"}], "]"}], "-", 
   RowBox[{"odomult", "[", 
    RowBox[{"MM", ",", "LL"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.444474929551526*^9, 3.444474951447485*^9}, {
  3.482245229518696*^9, 3.4822452338056927`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     SuperscriptBox["\[ExponentialE]", "x"]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "x"], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", "x"}], ")"}], " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", "x"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     RowBox[{"Sin", "[", "x", "]"}]}], ")"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", "x"]}], "-", 
     RowBox[{"x", " ", 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.444474940039806*^9, 3.444474952698388*^9}, 
   3.4446437362106247`*^9, 3.4456795673599863`*^9, 3.477817602850683*^9, 
   3.477925891665084*^9, 3.477926199775503*^9, 3.4786140506954527`*^9, 
   3.480936616621389*^9}]
}, Open  ]],

Cell["\<\
But, notice that this is not written in a nice form (there is more than one \
Dd^2 term!) and so you can simplify it with \"odosimp[]\":\
\>", "Text",
 CellChangeTimes->{{3.444474955815383*^9, 3.444474974684368*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odosimp", "[", "comm", "]"}]], "Input",
 CellChangeTimes->{{3.444474975853547*^9, 3.444474979453277*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["\[ExponentialE]", "x"], "+", 
  RowBox[{
   SuperscriptBox["Dd", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", "x", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"1", "+", "x"}], ")"}], " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{"Dd", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["\[ExponentialE]", "x"]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Sin", "[", "x", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.4444749801376762`*^9, 3.444643743610635*^9, 
  3.4456795675261097`*^9, 3.477817603029772*^9, 3.47792590205833*^9, 
  3.4779262026629047`*^9, 3.478614050746347*^9, 3.480936617751141*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["making a differential operator with specified kernel", "Subsection",
 CellChangeTimes->{{3.4779246321296864`*^9, 3.477924637865555*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"findK", "[", 
   RowBox[{"{", "f_", "}"}], "]"}], ":=", 
  RowBox[{"Dd", "-", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"f", ",", "x"}], "]"}], "/", "f"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"findK", "[", "vec_", "]"}], ":=", 
  RowBox[{"odosimp", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Wronskian", "[", 
      RowBox[{
       RowBox[{"Append", "[", 
        RowBox[{"vec", ",", 
         RowBox[{
          RowBox[{"ff", "'"}], "[", "x", "]"}]}], "]"}], ",", "x"}], "]"}], 
     "/", 
     RowBox[{"Wronskian", "[", 
      RowBox[{"vec", ",", "x"}], "]"}]}], "/.", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"ff", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "i_"}], "}"}]}], "]"}], "\[Rule]", 
     RowBox[{"Dd", "^", 
      RowBox[{"(", 
       RowBox[{"i", "-", "1"}], ")"}]}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4947760861855164`*^9, 3.494776111188076*^9}, {
  3.494776155142995*^9, 3.494776156532215*^9}, {3.494776214848794*^9, 
  3.494776215573865*^9}}],

Cell["\<\
The command above takes a list of functions of x as an argument and gives you \
back the lowest order monic differential operator which has all of them in \
its kernel.  For instance:\
\>", "Text",
 CellChangeTimes->{{3.443281901237433*^9, 3.443281928594616*^9}, {
  3.443281965616746*^9, 3.443281966760571*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"K", "=", 
  RowBox[{"findK", "[", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"E", "^", "x"}]}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.44328193038426*^9, 3.4432819372993593`*^9}, {
  3.443281980075144*^9, 3.443281981642398*^9}, {3.4779253336882763`*^9, 
  3.477925334165452*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["Dd", "2"], "+", 
  FractionBox["1", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "x"}]], "-", 
  FractionBox[
   RowBox[{"Dd", " ", "x"}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "x"}]]}]], "Output",
 CellChangeTimes->{
  3.4432819379664583`*^9, 3.44328198212838*^9, {3.4446439501514482`*^9, 
   3.4446439782879267`*^9}, 3.4446440122972116`*^9, 3.445679566634707*^9, 
   3.477817601913015*^9, {3.477924964830309*^9, 3.477924977559762*^9}, 
   3.4779250901594067`*^9, {3.477925139965361*^9, 3.477925162853797*^9}, {
   3.477925223254801*^9, 3.4779252358575487`*^9}, {3.477925299625949*^9, 
   3.477925334845455*^9}, 3.477925861152144*^9, 3.477926171071967*^9, 
   3.477926309070146*^9, 3.478614051033511*^9, 3.480936618714072*^9}]
}, Open  ]],

Cell["\<\
This means that d^2 -x/(x-1) d + 1/(x-1) is a differential operator that \
gives zero when applied to x or to E^x.  We can check this as follows:\
\>", "Text",
 CellChangeTimes->{{3.443281942635178*^9, 3.4432819927357817`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odoapply", "[", 
  RowBox[{"K", ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.443281996401932*^9, 3.443282021362648*^9}, {
  3.4432820533738422`*^9, 3.443282054665678*^9}, {3.477925338473609*^9, 
  3.477925343389269*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.443282023226446*^9, 3.4432820552670927`*^9, 
  3.445679566675528*^9, 3.477817601958742*^9, 3.477925344095747*^9, 
  3.477925863776291*^9, 3.47792617290136*^9, 3.4779263119874353`*^9, 
  3.478614051080494*^9, 3.4809366191187677`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"odoapply", "[", 
  RowBox[{"K", ",", 
   RowBox[{"Exp", "[", "x", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.443282030469554*^9, 3.443282060049877*^9}, {
  3.4779253473556843`*^9, 3.477925351110957*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.443282039964026*^9, 3.443282060601932*^9}, 
   3.445679566712105*^9, 3.477817602009164*^9, 3.477925351840745*^9, 
   3.477925864908877*^9, 3.47792617516605*^9, 3.477926313320218*^9, 
   3.4786140511293077`*^9, 3.480936619869413*^9}]
}, Open  ]],

Cell["Aha, it worked!", "Text",
 CellChangeTimes->{{3.443282072538954*^9, 3.443282075215414*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 10: KP", "Section",
 CellChangeTimes->{{3.445679588377763*^9, 3.445679592008327*^9}, {
  3.445692161453845*^9, 3.4456921617672243`*^9}, {3.445768660593342*^9, 
  3.4457686609214067`*^9}}],

Cell["\<\
This tests to see if u is a solution to the KP equation, returning \"0\" if \
it is:\
\>", "Text",
 CellChangeTimes->{{3.445767190257915*^9, 3.445767203040662*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"KP", "[", "u_", "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], "/", "4"}], "*", 
     RowBox[{"D", "[", 
      RowBox[{"u", ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], "+", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"u", ",", "t"}], "]"}], "-", 
       RowBox[{
        RowBox[{"1", "/", "4"}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", "*", "u", "*", 
           RowBox[{"D", "[", 
            RowBox[{"u", ",", "x"}], "]"}]}], "+", 
          RowBox[{"D", "[", 
           RowBox[{"u", ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}], ")"}]}]}], ",", "x"}],
      "]"}]}], "]"}]}]], "Input"],

Cell["\<\
This tests to see if tau is a solution to the bilinear KP equation, returning \
\"0\" if it is :\
\>", "Text",
 CellChangeTimes->{{3.445767205439644*^9, 3.445767221364169*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"bilinearKP", "[", "tau_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "newtau1", ",", "newtau2", ",", "prod", ",", "x1", ",", "x2", ",", "y1", 
      ",", "y2", ",", "z1", ",", "z2"}], "}"}], ",", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Applying bilinear KP equation to \>\"", ",", "tau"}], 
      "]"}], ";", "\n", 
     RowBox[{"newtau1", "=", 
      RowBox[{"tau", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "->", 
          RowBox[{"x1", "-", "y1"}]}], ",", 
         RowBox[{"y", "->", 
          RowBox[{"x2", "-", "y2"}]}], ",", 
         RowBox[{"t", "->", 
          RowBox[{"x3", "-", "y3"}]}]}], "}"}]}]}], ";", "\n", 
     RowBox[{"newtau2", "=", 
      RowBox[{"tau", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "->", 
          RowBox[{"x1", "+", "y1"}]}], ",", 
         RowBox[{"y", "->", 
          RowBox[{"x2", "+", "y2"}]}], ",", 
         RowBox[{"t", "->", 
          RowBox[{"x3", "+", "y3"}]}]}], "}"}]}]}], ";", "\n", 
     RowBox[{"prod", "=", 
      RowBox[{"newtau1", "*", "newtau2"}]}], ";", "\n", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"prod", ",", 
          RowBox[{"{", 
           RowBox[{"y1", ",", "4"}], "}"}]}], "]"}], "-", 
        RowBox[{"4", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{"prod", ",", "y3"}], "]"}], ",", "y1"}], "]"}]}], "+", 
        RowBox[{"3", 
         RowBox[{"D", "[", 
          RowBox[{"prod", ",", 
           RowBox[{"{", 
            RowBox[{"y2", ",", "2"}], "}"}]}], "]"}]}]}], " ", "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x1", "->", "x"}], ",", "\n", 
         RowBox[{"x2", "->", "y"}], ",", 
         RowBox[{"x3", "->", "t"}], ",", 
         RowBox[{"y1", "->", "0"}], ",", 
         RowBox[{"y2", "->", "0"}], ",", 
         RowBox[{"y3", "->", "0"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.414157134908945*^9, 3.414157146493334*^9}, {
   3.414157539681963*^9, 3.414157570952484*^9}, {3.4457670468487673`*^9, 
   3.445767055711692*^9}, {3.445767157028308*^9, 3.4457671684505367`*^9}, {
   3.4457673078314657`*^9, 3.445767317198688*^9}, {3.4777585974759808`*^9, 
   3.477758606524411*^9}, 3.477924418096677*^9}],

Cell["\<\
The command phi[lambda,n] makes a nicely weighted function by differentiating \
Exp[xz+yz^2+tz^3] n times with respect to z and evaluating it at z=lambda:\
\>", "Text",
 CellChangeTimes->{{3.445767229641271*^9, 3.445767261610092*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"phi", "[", 
   RowBox[{"lambda_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"z", " ", "x"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "2"}], " ", "y"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"z", "^", "3"}], " ", "t"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "n"}], "}"}]}], "]"}], "/.", 
    RowBox[{"z", "\[Rule]", "lambda"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.414157300430751*^9, 3.414157329903987*^9}, {
  3.41415741908654*^9, 3.414157442106514*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Chapter 11: Gamma_24 and the Geometric Origins of Bilinear KP\
\>", "Section",
 CellChangeTimes->{{3.478957560389926*^9, 3.478957569907987*^9}, {
  3.4790254793984613`*^9, 3.479025485244006*^9}, {3.480889651323081*^9, 
  3.480889652043229*^9}}],

Cell[CellGroupData[{

Cell["\<\
Could the Bilinear KP Equation be an algebraic equation \"in disguise\"?\
\>", "Subsection",
 CellChangeTimes->{{3.479023915526041*^9, 3.4790239421811743`*^9}, {
  3.4822453012280483`*^9, 3.4822453066581306`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Omega", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Wronskian", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"phi", "[", 
        RowBox[{"0", ",", 
         RowBox[{"i", "-", "1"}]}], "]"}], ",", 
       RowBox[{"phi", "[", 
        RowBox[{"0", ",", 
         RowBox[{"j", "-", "1"}]}], "]"}]}], "}"}], ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"gentau", "=", 
  RowBox[{
   RowBox[{"c12", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}], "+", 
   RowBox[{"c13", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"1", ",", "3"}], "]"}]}], "+", " ", 
   RowBox[{"c14", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"1", ",", "4"}], "]"}]}], "+", 
   RowBox[{"c23", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}], "+", " ", 
   RowBox[{"c24", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"2", ",", "4"}], "]"}]}], "+", " ", 
   RowBox[{"c34", " ", 
    RowBox[{"Omega", "[", 
     RowBox[{"3", ",", "4"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.479024292396372*^9, 3.479024334633787*^9}}],

Cell[BoxData[
 RowBox[{"c12", "+", 
  RowBox[{"2", " ", "c13", " ", "x"}], "+", 
  RowBox[{"c24", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "t"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
  RowBox[{"c23", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["x", "2"], "-", 
     RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
  RowBox[{"3", " ", "c14", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
  RowBox[{"c34", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "12"}], " ", "t", " ", "x"}], "+", 
     SuperscriptBox["x", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["y", "2"]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.479024322860708*^9}]
}, Open  ]],

Cell["\<\
When we plug the linear combination gentau into Bilinear KP we see the \
equation for a Grassmann Cone:\
\>", "Text",
 CellChangeTimes->{{3.479024325721566*^9, 3.4790243717132597`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bilinearKP", "[", "gentau", "]"}]], "Input",
 CellChangeTimes->{{3.4790243732139387`*^9, 3.479024377197227*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Applying bilinear KP equation to \"\>", "\[InvisibleSpace]", 
   RowBox[{"c12", "+", 
    RowBox[{"2", " ", "c13", " ", "x"}], "+", 
    RowBox[{"c24", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "6"}], " ", "t"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["x", "3"]}]}], ")"}]}], "+", 
    RowBox[{"c23", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
    RowBox[{"3", " ", "c14", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       RowBox[{"2", " ", "y"}]}], ")"}]}], "+", 
    RowBox[{"c34", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "12"}], " ", "t", " ", "x"}], "+", 
       SuperscriptBox["x", "4"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["y", "2"]}]}], ")"}]}]}]}],
  SequenceForm[
  "Applying bilinear KP equation to ", $CellContext`c12 + 
   2 $CellContext`c13 $CellContext`x + $CellContext`c24 ((-6) $CellContext`t + 
     2 $CellContext`x^3) + $CellContext`c23 ($CellContext`x^2 - 
     2 $CellContext`y) + 
   3 $CellContext`c14 ($CellContext`x^2 + 
     2 $CellContext`y) + $CellContext`c34 ((-12) $CellContext`t \
$CellContext`x + $CellContext`x^4 + 12 $CellContext`y^2)],
  Editable->False]], "Print",
 CellChangeTimes->{3.4790243777661037`*^9}],

Cell[BoxData[
 RowBox[{"288", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"c14", " ", "c23"}], "-", 
    RowBox[{"c13", " ", "c24"}], "+", 
    RowBox[{"c12", " ", "c34"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.479024377814373*^9}]
}, Open  ]],

Cell["\<\
Can we isolate the coefficients of gentau using derivatives?  Yes, if we make \
differential operators out of the polynomials Omega[i,j] themselves:\
\>", "Text",
 CellChangeTimes->{{3.479024385834835*^9, 3.479024416321136*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"P", "[", 
     RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Omega", "[", 
      RowBox[{"i", ",", "j"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", "ddx"}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "ddy"}]}], ",", 
       RowBox[{"t", "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "3"}], " ", "ddt"}]}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "\n"}]}]], "Input",
 CellChangeTimes->{{3.478957600151366*^9, 3.478957605829257*^9}, 
   3.478957782480482*^9, 3.479024287581407*^9, 3.4790244246184883`*^9, 
   3.479025323854292*^9}],

Cell["If you apply the differential operator:", "Text",
 CellChangeTimes->{{3.479024221343172*^9, 3.479024241212826*^9}, {
  3.47902427603307*^9, 3.4790242775335293`*^9}, {3.4790244328823023`*^9, 
  3.479024448137795*^9}, {3.479024481579006*^9, 3.479024484730932*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "[", 
  RowBox[{"2", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.479024450457358*^9, 3.479024451624709*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["ddx", "2"], "-", "ddy"}]], "Output",
 CellChangeTimes->{3.479024452123065*^9}]
}, Open  ]],

Cell["to gentau and then set (x,y,t)=(0,0,0) you get", "Text",
 CellChangeTimes->{{3.479024456052516*^9, 3.479024496387068*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"gentau", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "2"}], "}"}]}], "]"}], "-", 
   RowBox[{"D", "[", 
    RowBox[{"gentau", ",", "y"}], "]"}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "0"}], ",", 
    RowBox[{"y", "\[Rule]", "0"}], ",", 
    RowBox[{"t", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.479025160295576*^9, 3.4790251816006927`*^9}, {
  3.479025226695304*^9, 3.479025227347754*^9}}],

Cell[BoxData[
 RowBox[{"4", " ", "c23"}]], "Output",
 CellChangeTimes->{3.479025182794153*^9, 3.479025228846003*^9}]
}, Open  ]],

Cell["\<\
This isolates the coefficient c23 by applying P[2,3]!  Can we get c24 the \
same way?\
\>", "Text",
 CellChangeTimes->{{3.4790252459445467`*^9, 3.479025267038344*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"P", "[", 
  RowBox[{"2", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.479025272219893*^9, 3.479025273846054*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "ddt"}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["ddx", "3"]}]}]], "Output",
 CellChangeTimes->{3.479025274870278*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{"gentau", ",", "t"}], "]"}]}], "+", 
   RowBox[{"2", " ", 
    RowBox[{"D", "[", 
     RowBox[{"gentau", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}]}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "0"}], ",", 
    RowBox[{"y", "\[Rule]", "0"}], ",", 
    RowBox[{"t", "\[Rule]", "0"}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.479025281902566*^9, 3.479025303524034*^9}}],

Cell[BoxData[
 RowBox[{"36", " ", "c24"}]], "Output",
 CellChangeTimes->{3.4790253048846397`*^9}]
}, Open  ]],

Cell["\<\
Yes!

We can define  a command that will give us these differential expressions \
that isolate the coefficients\
\>", "Text",
 CellChangeTimes->{{3.479025307321755*^9, 3.479025372112855*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", 
   RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"P", "[", 
      RowBox[{"i", ",", "j"}], "]"}], " ", 
     RowBox[{"ddx", "^", "2"}], " ", 
     RowBox[{"ddy", "^", "2"}], " ", 
     RowBox[{"ddt", "^", "2"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"ddx", "^", "ii_"}], " ", 
     RowBox[{"ddy", "^", "jj_"}], " ", 
     RowBox[{"ddt", "^", "kk_"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{
        RowBox[{"ii", "-", "2"}], ",", 
        RowBox[{"jj", "-", "2"}], ",", 
        RowBox[{"kk", "-", "2"}]}], "]"}], "[", "tau", "]"}], "[", 
     RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"2", ",", "3"}], "]"}]], "Input",
 CellChangeTimes->{{3.478957819250658*^9, 3.4789578205005417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["tau", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"2", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{3.4789578209207497`*^9, 3.479025377927226*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.478957769971393*^9, 3.478957770759941*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["tau", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"4", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.4789577712601852`*^9, 3.478957809066749*^9}, 
   3.4790253798433123`*^9}]
}, Open  ]],

Cell["\<\
And we substitute those into the Plucker Relation (just as we substituted \
D[f/2,{x,2}], D[f/6,{y,3}],... into the equation for the sphere)\
\>", "Text",
 CellChangeTimes->{{3.479025382283551*^9, 3.47902543896247*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"plucker", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "2"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"3", ",", "4"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "3"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "4"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"c", "[", 
     RowBox[{"1", ",", "4"}], "]"}], 
    RowBox[{"c", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.478957880095435*^9, 3.478957905261107*^9}, {
  3.478957955854273*^9, 3.478957956738791*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["tau", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["tau", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"4", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.478957905913319*^9, 3.4789579574764347`*^9, 
  3.479025441521751*^9}]
}, Open  ]],

Cell["COULD THIS BE BILINEAR KP?!?", "Text",
 CellChangeTimes->{{3.4790254459248953`*^9, 3.4790254540185966`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bilinkp", "=", 
  RowBox[{"bilinearKP", "[", 
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478957959438107*^9, 3.478957980439797*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Applying bilinear KP equation to \"\>", "\[InvisibleSpace]", 
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}],
  SequenceForm["Applying bilinear KP equation to ", 
   $CellContext`tau[$CellContext`x, $CellContext`y, $CellContext`t]],
  Editable->False]], "Print",
 CellChangeTimes->{3.478957981301383*^9, 3.479025457388544*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["tau", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "y", ",", "t"}], "]"}], "2"]}], "+", 
  RowBox[{"8", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["tau", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"x", ",", "y", ",", "t"}], "]"}], "2"]}], "-", 
  RowBox[{"8", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"tau", "[", 
    RowBox[{"x", ",", "y", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "-", 
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["tau", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["tau", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"4", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"x", ",", "y", ",", "t"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.478957981345232*^9, 3.479025457448593*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"2", "plucker"}], "-", "bilinkp"}], "]"}]], "Input",
 CellChangeTimes->{{3.478958179069852*^9, 3.478958183456942*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4789581840684967`*^9, 3.4790254604023046`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chapter 13: Gamma_kn and the Bilinear KP Hierarchy", "Section",
 CellChangeTimes->{{3.478957560389926*^9, 3.478957569907987*^9}, {
  3.4790254793984613`*^9, 3.479025485244006*^9}, {3.48088962576777*^9, 
  3.480889654796876*^9}}],

Cell[CellGroupData[{

Cell["Making Bilinear PDEs from Plucker Relations with k=3 and n=6", \
"Subsection",
 CellChangeTimes->{{3.479023915526041*^9, 3.4790239421811743`*^9}, {
  3.480889679161359*^9, 3.480889720285761*^9}}],

Cell["\<\
Since n=6, we will need FIVE variables.  We make a new definition for \"phi\" \
(the nicely weighted functions) that will work:\
\>", "Text",
 CellChangeTimes->{{3.480889788832213*^9, 3.480889812763612*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"newphi", "[", 
   RowBox[{"lambda_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"t1", " ", "z"}], " ", "+", " ", 
       RowBox[{"t2", " ", 
        RowBox[{"z", "^", "2"}]}], " ", "+", " ", 
       RowBox[{"t3", " ", 
        RowBox[{"z", "^", "3"}]}], " ", "+", " ", 
       RowBox[{"t4", " ", 
        RowBox[{"z", "^", "4"}]}], " ", "+", " ", 
       RowBox[{"t5", " ", 
        RowBox[{"z", "^", "5"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"z", ",", "n"}], "}"}]}], "]"}], "/.", 
   RowBox[{"z", "\[Rule]", "lambda"}]}]}]], "Input",
 CellChangeTimes->{{3.480889814675468*^9, 3.480889852786428*^9}, {
  3.480889914226462*^9, 3.480889919212367*^9}}],

Cell["\<\
The command below applies the operator P[i1,i2,i3] to the arbitrary function \
tau[t1,t2,t3,t4,t5]:\
\>", "Text",
 CellChangeTimes->{{3.479025307321755*^9, 3.479025372112855*^9}, {
  3.48089011538062*^9, 3.480890150780601*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"c", "[", 
   RowBox[{"i1_", ",", "i2_", ",", "i3_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Wronskian", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i1", "-", "1"}]}], "]"}], ",", 
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i2", "-", "1"}]}], "]"}], ",", 
           RowBox[{"newphi", "[", 
            RowBox[{"0", ",", 
             RowBox[{"i3", "-", "1"}]}], "]"}]}], "}"}], ",", "t1"}], "]"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"t1", "\[Rule]", "ddt1"}], ",", 
         RowBox[{"t2", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "2"}], " ", "ddt2"}]}], ",", 
         RowBox[{"t3", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "3"}], " ", "ddt3"}]}], ",", 
         RowBox[{"t4", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "4"}], " ", "ddt4"}]}], ",", 
         RowBox[{"t5", "\[Rule]", 
          RowBox[{
           RowBox[{"1", "/", "5"}], " ", "ddt5"}]}]}], "}"}]}], ")"}], " ", 
     RowBox[{"ddt1", "^", "2"}], " ", 
     RowBox[{"ddt2", "^", "2"}], " ", 
     RowBox[{"ddt3", "^", "2"}], " ", 
     RowBox[{"ddt4", "^", "2"}], " ", 
     RowBox[{"ddt5", "^", "2"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], 
    "]"}], "/.", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ddt1", "^", "j1_"}], " ", 
     RowBox[{"ddt2", "^", "j2_"}], " ", 
     RowBox[{"ddt3", "^", "j3_"}], " ", 
     RowBox[{"ddt4", "^", "j4_"}], " ", 
     RowBox[{"ddt5", "^", "j5_"}], " ", 
     RowBox[{"tau", "[", 
      RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], 
    "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", 
       RowBox[{
        RowBox[{"j1", "-", "2"}], ",", 
        RowBox[{"j2", "-", "2"}], ",", 
        RowBox[{"j3", "-", "2"}], ",", 
        RowBox[{"j4", "-", "2"}], ",", 
        RowBox[{"j5", "-", "2"}]}], "]"}], "[", "tau", "]"}], "[", 
     RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.480890153129841*^9, 3.480890254473042*^9}, {
  3.4808903646072083`*^9, 3.480890368174728*^9}, {3.48089070528187*^9, 
  3.480890717031369*^9}, {3.4808908693944883`*^9, 3.480890876924096*^9}, {
  3.4808935525914373`*^9, 3.48089363566728*^9}, {3.480932393064308*^9, 
  3.480932408314354*^9}, {3.4831786439185*^9, 3.48317864406774*^9}, {
  3.4831787030762444`*^9, 3.4831787032663307`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c", "[", 
  RowBox[{"2", ",", "3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.478957819250658*^9, 3.4789578205005417`*^9}, {
  3.4808902751318073`*^9, 3.480890275828148*^9}, {3.48089351248279*^9, 
  3.48089351346633*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "1", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], "-", 
  
  RowBox[{"6", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], "]"}]}], "+", 
  
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["tau", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"3", ",", "0", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t1", ",", "t2", ",", "t3", ",", "t4", ",", "t5"}], 
    "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.4789578209207497`*^9, 3.479025377927226*^9, 3.480890276547874*^9, 
   3.480890370767049*^9, 3.480890671848064*^9, 3.480890708911212*^9, 
   3.4808908793797073`*^9, 3.4808935183761883`*^9, 3.480893560678153*^9, {
   3.480893591210997*^9, 3.4808936145841627`*^9}, 3.480893646469705*^9, 
   3.4831786730464*^9, 3.483178705562519*^9}]
}, Open  ]],

Cell["\<\
Now we substitute those into the two (of many) Plucker relations we found for \
Gamma_36:\
\>", "Text",
 CellChangeTimes->{{3.479025382283551*^9, 3.47902543896247*^9}, {
  3.480890896763679*^9, 3.480890914098184*^9}}],

Cell[BoxData[
 RowBox[{"longplucker", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2", ",", "3"}], "]"}]}], 
     RowBox[{"c", "[", 
      RowBox[{"4", ",", "5", ",", "6"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3", ",", "4"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "5", ",", "6"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3", ",", "5"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "4", ",", "6"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "3", ",", "6"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "4", ",", "5"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.478957880095435*^9, 3.478957905261107*^9}, {
   3.478957955854273*^9, 3.478957956738791*^9}, {3.480890968312624*^9, 
   3.480891038346841*^9}, {3.4808910693637743`*^9, 3.480891079815074*^9}, 
   3.4808916811598177`*^9, 3.480932780250244*^9}],

Cell[BoxData[
 RowBox[{"shortplucker", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"c", "[", 
       RowBox[{"1", ",", "2", ",", "3"}], "]"}]}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "4", ",", "5"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2", ",", "4"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3", ",", "5"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"1", ",", "2", ",", "5"}], "]"}], 
     RowBox[{"c", "[", 
      RowBox[{"2", ",", "3", ",", "4"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.480891104729432*^9, 3.4808911271987143`*^9}, 
   3.480891688247321*^9, 3.480891776621009*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["producing solutions as Wronskian determinants", "Subsection",
 CellChangeTimes->{{3.480936585797607*^9, 3.480936593273181*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"trytau", "=", 
  RowBox[{"Wronskian", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"newphi", "[", 
        RowBox[{"1", ",", "0"}], "]"}], "+", 
       RowBox[{"newphi", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "0"}], "]"}]}], ",", 
      RowBox[{"newphi", "[", 
       RowBox[{"0", ",", "5"}], "]"}], ",", 
      RowBox[{
       RowBox[{"newphi", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "+", 
       RowBox[{"newphi", "[", 
        RowBox[{"1", ",", "0"}], "]"}]}]}], "}"}], ",", "t1"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.480933323153994*^9, 3.480933389360365*^9}}],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"t2", "+", "t4"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t2", "+", "t4"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "5"], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["t1", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
       RowBox[{"60", " ", 
        SuperscriptBox["t1", "2"], " ", "t3"}], "+", 
       RowBox[{"60", " ", "t1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
          RowBox[{"2", " ", "t4"}]}], ")"}]}], "+", 
       RowBox[{"120", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3"}], "+", "t5"}],
          ")"}]}]}], ")"}]}], "-", 
    RowBox[{"5", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "4"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
       RowBox[{"24", " ", "t1", " ", "t3"}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["t2", "2"], "+", 
          RowBox[{"2", " ", "t4"}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"Cosh", "[", 
      RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}], "+", 
    RowBox[{"20", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["t1", "3"], "+", 
       RowBox[{"6", " ", "t1", " ", "t2"}], "+", 
       RowBox[{"6", " ", "t3"}]}], ")"}], " ", 
     RowBox[{"Sinh", "[", 
      RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.480933398317713*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tau", "[", 
   RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_", ",", "t5_"}], "]"}], ":=", 
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t2", "+", "t4"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"t2", "+", "t4"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t1", "5"], "+", 
        RowBox[{"20", " ", 
         SuperscriptBox["t1", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "t2"}], ")"}]}], "+", 
        RowBox[{"60", " ", 
         SuperscriptBox["t1", "2"], " ", "t3"}], "+", 
        RowBox[{"60", " ", "t1", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "t2"}], ")"}], " ", "t2"}], "+", 
           RowBox[{"2", " ", "t4"}]}], ")"}]}], "+", 
        RowBox[{"120", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", "t2"}], ")"}], " ", "t3"}], "+", 
           "t5"}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"5", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t1", "4"], "+", 
        RowBox[{"12", " ", 
         SuperscriptBox["t1", "2"], " ", "t2"}], "+", 
        RowBox[{"24", " ", "t1", " ", "t3"}], "+", 
        RowBox[{"12", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["t2", "2"], "+", 
           RowBox[{"2", " ", "t4"}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Cosh", "[", 
       RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}], "+", 
     RowBox[{"20", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["t1", "3"], "+", 
        RowBox[{"6", " ", "t1", " ", "t2"}], "+", 
        RowBox[{"6", " ", "t3"}]}], ")"}], " ", 
      RowBox[{"Sinh", "[", 
       RowBox[{"t1", "+", "t3", "+", "t5"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.4809334161452*^9, 3.480933439559031*^9}}],

Cell[CellGroupData[{

Cell[BoxData["longplucker"], "Input",
 CellChangeTimes->{{3.480933442876646*^9, 3.480933447910912*^9}}],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   PanelBox[GridBox[{
      {
       StyleBox[
        StyleBox[
         DynamicBox[ToBoxes[
           FEPrivate`FrontEndResource["FEStrings", "sizeExplanation"], 
           StandardForm],
          ImageSizeCache->{278., {3., 8.}}],
         StripOnInput->False,
         DynamicUpdating->True], "Panel",
        StripOnInput->False,
        Background->None]},
      {
       ItemBox[
        TagBox[
         RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}],
         Short[#, 5]& ],
        Background->GrayLevel[1],
        BaseStyle->{Deployed -> False},
        Frame->True,
        FrameStyle->GrayLevel[0, 0.2],
        StripOnInput->False]},
      {
       RowBox[{
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowLess"], 
             StandardForm],
            ImageSizeCache->{49., {1., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 17, 22809088085851720179, 5/2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowMore"], 
             StandardForm],
            ImageSizeCache->{52., {1., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 17, 22809088085851720179, 5 2],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeShowAll"], 
             StandardForm],
            ImageSizeCache->{82., {2., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>OutputSizeLimit`ButtonFunction[
          Identity, 17, 22809088085851720179, Infinity],
         Enabled->True,
         Evaluator->Automatic,
         Method->"Queued"], "\[ThinSpace]", 
        ButtonBox[
         StyleBox[
          StyleBox[
           DynamicBox[ToBoxes[
             FEPrivate`FrontEndResource["FEStrings", "sizeChangeLimit"], 
             StandardForm],
            ImageSizeCache->{74., {1., 8.}}],
           StripOnInput->False,
           DynamicUpdating->True], "Panel",
          StripOnInput->False,
          Background->None],
         Appearance->Automatic,
         ButtonFunction:>FrontEndExecute[{
            FrontEnd`SetOptions[
            FrontEnd`$FrontEnd, 
             FrontEnd`PreferencesSettings -> {"Page" -> "Evaluation"}], 
            FrontEnd`FrontEndToken["PreferencesDialog"]}],
         Evaluator->None,
         Method->"Preemptive"]}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[1.2]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    DefaultBaseStyle->{},
    FrameMargins->5],
   Deploy,
   DefaultBaseStyle->{Deployed -> True}],
  Out[17]]], "Output",
 CellChangeTimes->{3.4809334494800777`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "%", "]"}]], "Input",
 CellChangeTimes->{{3.480933450758684*^9, 3.4809334528471003`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.480933453756077*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "shortplucker", "]"}]], "Input",
 CellChangeTimes->{{3.4809334548247023`*^9, 3.480933458361225*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.480933459390708*^9, 3.4809335311031*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowSize->{742, 598},
WindowMargins->{{49, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"7.0 for Mac OS X PowerPC (32-bit) (February 18, 2009)",
StyleDefinitions->FrontEnd`FileName[{"Book"}, "Textbook.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 188, 5, 123, "Title"],
Cell[758, 29, 120, 4, 89, "Subtitle"],
Cell[CellGroupData[{
Cell[903, 37, 222, 3, 54, "Section"],
Cell[1128, 42, 340, 6, 20, "Text"],
Cell[1471, 50, 2040, 59, 88, "Input"],
Cell[3514, 111, 655, 12, 80, "Text"],
Cell[4172, 125, 2322, 61, 134, "Code",
 InitializationCell->False]
}, Closed]],
Cell[CellGroupData[{
Cell[6531, 191, 225, 3, 34, "Section"],
Cell[6759, 196, 4501, 126, 133, "Input"],
Cell[11263, 324, 611, 10, 50, "Text"],
Cell[11877, 336, 277, 5, 20, "Text"],
Cell[12157, 343, 419, 13, 43, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[12613, 361, 454, 8, 52, "Section"],
Cell[13070, 371, 324, 6, 35, "Text"],
Cell[13397, 379, 292, 8, 27, "Input"],
Cell[13692, 389, 742, 23, 27, "Input"],
Cell[14437, 414, 320, 6, 20, "Text"],
Cell[14760, 422, 489, 14, 27, "Input"],
Cell[15252, 438, 489, 14, 27, "Input"],
Cell[15744, 454, 313, 5, 35, "Text"],
Cell[16060, 461, 1717, 53, 58, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[17814, 519, 230, 3, 34, "Section"],
Cell[18047, 524, 275, 5, 20, "Text"],
Cell[18325, 531, 510, 17, 27, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18872, 553, 165, 2, 34, "Section"],
Cell[19040, 557, 174, 4, 20, "Text"],
Cell[19217, 563, 335, 10, 27, "Input"],
Cell[19555, 575, 400, 6, 35, "Text"],
Cell[CellGroupData[{
Cell[19980, 585, 124, 2, 27, "Input"],
Cell[20107, 589, 204, 5, 47, "Output"]
}, Open  ]],
Cell[20326, 597, 1904, 50, 103, "Input"],
Cell[22233, 649, 725, 13, 80, "Text"],
Cell[CellGroupData[{
Cell[22983, 666, 338, 10, 27, "Input"],
Cell[23324, 678, 1024, 32, 50, "Output"]
}, Open  ]],
Cell[24363, 713, 304, 5, 35, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[24704, 723, 313, 4, 34, "Section"],
Cell[CellGroupData[{
Cell[25042, 731, 121, 1, 34, "Subsection"],
Cell[25166, 734, 1087, 28, 83, "Input"],
Cell[26256, 764, 253, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[26534, 773, 237, 7, 37, "Input"],
Cell[26774, 782, 333, 8, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27144, 795, 304, 7, 37, "Input"],
Cell[27451, 804, 540, 14, 61, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28040, 824, 221, 3, 34, "Subsection"],
Cell[28264, 829, 108, 1, 26, "Text"],
Cell[28375, 832, 2818, 76, 173, "Input"],
Cell[31196, 910, 165, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[31386, 917, 419, 11, 53, "Input"],
Cell[31808, 930, 342, 7, 40, "Output"],
Cell[32153, 939, 382, 8, 40, "Output"]
}, Open  ]],
Cell[32550, 950, 138, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[32713, 955, 151, 3, 37, "Input"],
Cell[32867, 960, 950, 29, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33854, 994, 202, 4, 37, "Input"],
Cell[34059, 1000, 985, 29, 43, "Output"]
}, Open  ]],
Cell[35059, 1032, 119, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[35203, 1037, 316, 8, 37, "Input"],
Cell[35522, 1047, 1352, 41, 43, "Output"]
}, Open  ]],
Cell[36889, 1091, 226, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[37140, 1099, 129, 2, 37, "Input"],
Cell[37272, 1103, 798, 23, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38119, 1132, 142, 1, 34, "Subsection"],
Cell[38264, 1135, 1083, 33, 53, "Input"],
Cell[39350, 1170, 322, 6, 41, "Text"],
Cell[CellGroupData[{
Cell[39697, 1180, 323, 8, 37, "Input"],
Cell[40023, 1190, 770, 17, 56, "Output"]
}, Open  ]],
Cell[40808, 1210, 237, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[41070, 1218, 250, 5, 37, "Input"],
Cell[41323, 1225, 282, 4, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41642, 1234, 232, 5, 37, "Input"],
Cell[41877, 1241, 283, 4, 37, "Output"]
}, Open  ]],
Cell[42175, 1248, 97, 1, 26, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[42321, 1255, 201, 3, 34, "Section"],
Cell[42525, 1260, 174, 4, 20, "Text"],
Cell[42702, 1266, 840, 28, 27, "Input"],
Cell[43545, 1296, 186, 4, 20, "Text"],
Cell[43734, 1302, 2423, 64, 103, "Input"],
Cell[46160, 1368, 244, 4, 20, "Text"],
Cell[46407, 1374, 671, 19, 27, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[47115, 1398, 254, 5, 34, "Section"],
Cell[CellGroupData[{
Cell[47394, 1407, 223, 4, 31, "Subsection"],
Cell[CellGroupData[{
Cell[47642, 1415, 1169, 36, 58, "Input"],
Cell[48814, 1453, 834, 28, 33, "Output"]
}, Open  ]],
Cell[49663, 1484, 195, 4, 20, "Text"],
Cell[CellGroupData[{
Cell[49883, 1492, 136, 2, 27, "Input"],
Cell[50022, 1496, 1422, 39, 26, "Print"],
Cell[51447, 1537, 238, 7, 27, "Output"]
}, Open  ]],
Cell[51700, 1547, 238, 4, 20, "Text"],
Cell[51941, 1553, 715, 21, 73, "Input"],
Cell[52659, 1576, 268, 3, 20, "Text"],
Cell[CellGroupData[{
Cell[52952, 1583, 143, 3, 27, "Input"],
Cell[53098, 1588, 120, 3, 30, "Output"]
}, Open  ]],
Cell[53233, 1594, 128, 1, 20, "Text"],
Cell[CellGroupData[{
Cell[53386, 1599, 511, 15, 27, "Input"],
Cell[53900, 1616, 116, 2, 27, "Output"]
}, Open  ]],
Cell[54031, 1621, 177, 4, 20, "Text"],
Cell[CellGroupData[{
Cell[54233, 1629, 143, 3, 27, "Input"],
Cell[54379, 1634, 186, 6, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54602, 1645, 534, 17, 27, "Input"],
Cell[55139, 1664, 97, 2, 27, "Output"]
}, Open  ]],
Cell[55251, 1669, 201, 6, 50, "Text"],
Cell[55455, 1677, 932, 28, 43, "Input"],
Cell[CellGroupData[{
Cell[56412, 1709, 145, 3, 27, "Input"],
Cell[56560, 1714, 564, 19, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57161, 1738, 143, 3, 27, "Input"],
Cell[57307, 1743, 851, 29, 30, "Output"]
}, Open  ]],
Cell[58173, 1775, 229, 4, 20, "Text"],
Cell[CellGroupData[{
Cell[58427, 1783, 596, 19, 27, "Input"],
Cell[59026, 1804, 3091, 104, 73, "Output"]
}, Open  ]],
Cell[62132, 1911, 114, 1, 20, "Text"],
Cell[CellGroupData[{
Cell[62271, 1916, 224, 5, 27, "Input"],
Cell[62498, 1923, 399, 8, 20, "Print"],
Cell[62900, 1933, 2586, 88, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65523, 2026, 181, 4, 27, "Input"],
Cell[65707, 2032, 96, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[65864, 2040, 234, 3, 34, "Section"],
Cell[CellGroupData[{
Cell[66123, 2047, 201, 3, 34, "Subsection"],
Cell[66327, 2052, 217, 4, 26, "Text"],
Cell[66547, 2058, 786, 22, 37, "Input"],
Cell[67336, 2082, 237, 5, 26, "Text"],
Cell[67576, 2089, 2721, 71, 128, "Input"],
Cell[CellGroupData[{
Cell[70322, 2164, 253, 5, 37, "Input"],
Cell[70578, 2171, 1287, 37, 40, "Output"]
}, Open  ]],
Cell[71880, 2211, 227, 5, 26, "Text"],
Cell[72110, 2218, 1047, 28, 37, "Input"],
Cell[73160, 2248, 734, 21, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[73931, 2274, 133, 1, 34, "Subsection"],
Cell[CellGroupData[{
Cell[74089, 2279, 658, 20, 37, "Input"],
Cell[74750, 2301, 1892, 57, 63, "Output"]
}, Open  ]],
Cell[76657, 2361, 2087, 60, 78, "Input"],
Cell[CellGroupData[{
Cell[78769, 2425, 103, 1, 37, "Input"],
Cell[78875, 2428, 4126, 119, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83038, 2552, 129, 2, 37, "Input"],
Cell[83170, 2556, 70, 1, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[83277, 2562, 140, 2, 37, "Input"],
Cell[83420, 2566, 90, 1, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)